@@ -172,6 +172,8 @@ def create_specialties_flag(df):
     return df
 
 
+
+
 def set_idemailstatus_target_column(df):
 
     if ('IDEmailStatus' in df.columns):
@@ -278,6 +280,20 @@ def create_company_years_column(df):
     return df
 
 
+def clean_companytype(df):
+    df.loc[
+        df['Type'] != 'Educational Institution' &
+        df['Type'] != 'Government Agency' &
+        df['Type'] != 'Government Agency' &
+        df['Type'] != 'Nonprofit' &
+        df['Type'] != 'Partnership' &
+        df['Type'] != 'Privately Held' &
+        df['Type'] != 'Public Company' &
+        df['Type'] != 'Self-Employed',
+        'Type'    ] = 'Unknown'
+    return df
+
+
 def fill_seniority_column(df):
     """Defines new cases for Seniority and sets the rest to 'other'
 
